pubs

# XMLRésuméLibrary: User Guide

publisher | Element Reference | referee

## Name

pubs — A group of one or more publications

## Synopsis

### Content Model

    (pub+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `pubs` element groups together one or more publications.

### Parents

`pubs` may be contained in these elements: `resume`

## Examples

    <pubs>
      <pub>
        <bookTitle>General Relativity for Idiots</bookTitle>
        <author>Einstein</author>
      </pub>
      <pub>
        <artTitle>String Theory for Dummies</artTitle>
        <bookTitle>Topics in Physics</bookTitle>
        <author>Stephen Hawking</author>
      </pub>
    </pubs>

publisher | Element Reference | referee